@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use parent qw( Alien::Base );
 
-our $VERSION = '1.03';
+our $VERSION = '1.04';
 
 
 1;
@@ -21,8 +21,6 @@ Alien::feexl - Compile the FreeXL library
  
 <p>
     <img src="https://img.shields.io/badge/perl-5.10+-blue.svg" alt="Requires Perl 5.10+" />
-    <a href="https://travis-ci.org/shawnlaffan/perl-alien-freexl"><img src="https://travis-ci.org/shawnlaffan/perl-alien-freexl.svg?branch=master" /></a>
-    <a href="https://ci.appveyor.com/project/shawnlaffan/perl-alien-freexl"><img src="https://ci.appveyor.com/api/projects/status/weou0nr12huxqa72?svg=true" /></a>
 </p>
 
 =end HTML
